==> syncthingtray_1.3.2.orig.tar.xz: syncthingtray-1.3.2/plasmoid/translations/syncthingplasmoid_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>DetailView</name>
    <message>
        <location filename="../package/contents/ui/DetailView.qml" line="14"/>
        <source>Copy value</source>
        <translation>复制值</translation>
    </message>
</context>
<context>
    <name>DevicesPage</name>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="64"/>
        <source>Resume</source>
        <translation>恢复</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="64"/>
        <location filename="../package/contents/ui/DevicesPage.qml" line="116"/>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="102"/>
        <source>Copy name</source>
        <translation>复制名字</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="107"/>
        <source>Copy ID</source>
        <translation>复制 ID</translation>
    </message>
</context>
<context>
    <name>DirectoriesPage</name>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="71"/>
        <source>Show errors</source>
        <translation>显示错误</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="82"/>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="151"/>
        <source>Rescan</source>
        <translation>重新扫描</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="90"/>
        <source>Resume</source>
        <translation>恢复</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="90"/>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="158"/>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="100"/>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="165"/>
        <source>Open in file browser</source>
        <translation>在文件浏览器中打开</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="137"/>
        <source>Copy label/ID</source>
        <translation>复制标签/ID</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="142"/>
        <source>Copy path</source>
        <translation>复制路径</translation>
    </message>
</context>
<context>
    <name>DownloadsPage</name>
    <message>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="67"/>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="123"/>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="148"/>
        <source>Open in file browser</source>
        <translation>在文件浏览器中打开</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="139"/>
        <source>Copy label/ID</source>
        <translation>复制标签/ID</translation>
    </message>
</context>
<context>
    <name>FullRepresentation</name>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="192"/>
        <source>Connect</source>
        <translation>连接</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="208"/>
        <source>Resume</source>
        <translation>恢复</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="217"/>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="267"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="281"/>
        <source>Start</source>
        <translation>启动</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="337"/>
        <source>Show new notifications</source>
        <translation>显示新通知</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="351"/>
        <source>About Syncthing Tray</source>
        <translation>关于 Syncthing Tray</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="372"/>
        <source>Show own device ID</source>
        <translation>显示本设备 ID</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="387"/>
        <source>Show Syncthing log</source>
        <translation>显示 Syncthing 日志</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="399"/>
        <source>Rescan all directories</source>
        <translation>重新扫描所有目录</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="414"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="435"/>
        <source>Open Syncthing</source>
        <translation>打开 Syncthing</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="483"/>
        <source>Global</source>
        <translation>全局</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="492"/>
        <source>Global incoming traffic</source>
        <translation>全局下载流量</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="503"/>
        <source>Local</source>
        <translation>本地</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="512"/>
        <source>Global outgoing traffic</source>
        <translation>本地上传流量</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="569"/>
        <source>Toggle filter</source>
        <translation>切换过滤器</translation>
    </message>
</context>
<context>
    <name>Plasmoid::AppearanceOptionPage</name>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="6"/>
        <source>Appearance</source>
        <translation>外观</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="25"/>
        <source>Size of directory/device/download list</source>
        <translation>目录/设备/下载列表的大小</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="78"/>
        <source> x </source>
        <translation> x </translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="104"/>
        <source> grid units</source>
        <translation> 网格单元</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="122"/>
        <source>Note that the size is ignored when the Plasmoid is displayed on the desktop or in full screen mode. When displayed as entry of the system tray Plasmoid the size can not be changed (setting a high value just leads to the contents being clipped).</source>
        <translation>请注意，当 Plasmoid 显示在桌面上或以全屏模式显示时，将忽略大小。当显示为系统托盘条目时，大小无法更改（设置过高值只会导致内容被剪裁）。</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="134"/>
        <source>States to enable passive mode</source>
        <translation>启用被动模式的状态</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="35"/>
        <source>Colors</source>
        <translation>颜色</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="42"/>
        <source>Bright custom text colors (use for dark color scheme)</source>
        <translation>明亮的自定义文本颜色（用于深色方案）</translation>
    </message>
</context>
<context>
    <name>Plasmoid::Settings</name>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="29"/>
        <source>The settings on this page are specific to the current instance of the Plasmoid.</source>
        <translation>此页面上的设置特定于 Plasmoid 的当前实例。</translation>
    </message>
</context>
<context>
    <name>Plasmoid::SettingsDialog</name>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="126"/>
        <source>Plasmoid</source>
        <translation>Plasmoid</translation>
    </message>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="134"/>
        <source>Web view</source>
        <translation>网页视图</translation>
    </message>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="140"/>
        <source>Extras</source>
        <translation>额外</translation>
    </message>
</context>
<context>
    <name>Plasmoid::ShortcutOptionPage</name>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="66"/>
        <source>Shortcuts</source>
        <translation>快捷方式</translation>
    </message>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="72"/>
        <source>Global shortcut</source>
        <translation>全局快捷方式</translation>
    </message>
</context>
<context>
    <name>Plasmoid::SyncthingApplet</name>
    <message>
        <location filename="../lib/syncthingapplet.cpp" line="342"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <location filename="../lib/syncthingapplet.cpp" line="354"/>
        <source>New notifications</source>
        <translation>新通知</translation>
    </message>
    <message>
        <location filename="../lib/syncthingapplet.cpp" line="510"/>
        <source>D-Bus error - unable to </source>
        <translation>D-Bus 错误 - 无法 </translation>
    </message>
</context>
<context>
    <name>RecentChangesPage</name>
    <message>
        <location filename="../package/contents/ui/RecentChangesPage.qml" line="100"/>
        <source>Copy path</source>
        <translation>复制路径</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/RecentChangesPage.qml" line="105"/>
        <source>Copy device ID</source>
        <translation>复制设备 ID</translation>
    </message>
</context>
<context>
    <name>StatisticsView</name>
    <message>
        <location filename="../package/contents/ui/StatisticsView.qml" line="12"/>
        <source> files</source>
        <translation> 文件</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/StatisticsView.qml" line="17"/>
        <source> directories</source>
        <translation> 目录</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/StatisticsView.qml" line="23"/>
        <source> size</source>
        <translation> 大小</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../package/contents/ui/main.qml" line="67"/>
        <source>Open Syncthing</source>
        <translation>打开 Syncthing</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="69"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="70"/>
        <source>Log</source>
        <translation>日志</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="71"/>
        <source>Internal errors</source>
        <translation>内部错误</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="72"/>
        <source>Rescan all directories</source>
        <translation>重新扫描所有目录</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="74"/>
        <source>Restart Syncthing</source>
        <translation>重启 Syncthing</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="76"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
</context>
</TS>

==> syncthingtray_1.7.5.orig.tar.xz: syncthingtray-1.7.5/plasmoid/translations/syncthingplasmoid_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>DetailView</name>
    <message>
        <location filename="../package/contents/ui/DetailView.qml" line="14"/>
        <source>Copy value</source>
        <translation>复制值</translation>
    </message>
</context>
<context>
    <name>DevicesPage</name>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="64"/>
        <source>Resume</source>
        <translation>恢复</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="64"/>
        <location filename="../package/contents/ui/DevicesPage.qml" line="116"/>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="102"/>
        <source>Copy name</source>
        <translation>复制名字</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="107"/>
        <source>Copy ID</source>
        <translation>复制 ID</translation>
    </message>
</context>
<context>
    <name>DirectoriesPage</name>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="71"/>
        <source>Show errors</source>
        <translation>显示错误</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="82"/>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="151"/>
        <source>Rescan</source>
        <translation>重新扫描</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="90"/>
        <source>Resume</source>
        <translation>恢复</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="90"/>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="158"/>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="100"/>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="165"/>
        <source>Open in file browser</source>
        <translation>在文件浏览器中打开</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="137"/>
        <source>Copy label/ID</source>
        <translation>复制标签/ID</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="142"/>
        <source>Copy path</source>
        <translation>复制路径</translation>
    </message>
</context>
<context>
    <name>DownloadsPage</name>
    <message>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="67"/>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="123"/>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="148"/>
        <source>Open in file browser</source>
        <translation>在文件浏览器中打开</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="139"/>
        <source>Copy label/ID</source>
        <translation>复制标签/ID</translation>
    </message>
</context>
<context>
    <name>FullRepresentation</name>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="192"/>
        <source>Connect</source>
        <translation>连接</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="208"/>
        <source>Resume</source>
        <translation>恢复</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="217"/>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="267"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="281"/>
        <source>Start</source>
        <translation>启动</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="337"/>
        <source>Show new notifications</source>
        <translation>显示新通知</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="351"/>
        <source>About Syncthing Tray</source>
        <translation>关于 Syncthing Tray</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="372"/>
        <source>Show own device ID</source>
        <translation>显示本设备 ID</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="387"/>
        <source>Show Syncthing log</source>
        <translation>显示 Syncthing 日志</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="399"/>
        <source>Rescan all folders</source>
        <translation>重新扫描所有目录</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="414"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="435"/>
        <source>Open Syncthing</source>
        <translation>打开 Syncthing</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="483"/>
        <source>Global</source>
        <translation>全局</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="492"/>
        <source>Global incoming traffic</source>
        <translation>全局下载流量</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="503"/>
        <source>Local</source>
        <translation>本地</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="512"/>
        <source>Global outgoing traffic</source>
        <translation>本地上传流量</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="569"/>
        <source>Toggle filter</source>
        <translation>切换过滤器</translation>
    </message>
</context>
<context>
    <name>Plasmoid::AppearanceOptionPage</name>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="6"/>
        <source>Appearance</source>
        <translation>外观</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="25"/>
        <source>Size of folder/device/download list</source>
        <translation>目录/设备/下载列表的大小</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="78"/>
        <source> x </source>
        <translation> x </translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="104"/>
        <source> grid units</source>
        <translation> 网格单元</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="122"/>
        <source>Note that the size is ignored when the Plasmoid is displayed on the desktop or in full screen mode. When displayed as entry of the system tray Plasmoid the size can not be changed (setting a high value just leads to the contents being clipped).</source>
        <translation>请注意，当 Plasmoid 显示在桌面上或以全屏模式显示时，将忽略大小。当显示为系统托盘条目时，大小无法更改（设置过高值只会导致内容被剪裁）。</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="134"/>
        <source>States to enable passive mode</source>
        <translation>启用被动模式的状态</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="35"/>
        <source>Colors</source>
        <translation>颜色</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="42"/>
        <source>Bright custom text colors (use for dark color scheme)</source>
        <translation>明亮的自定义文本颜色（用于深色方案）</translation>
    </message>
</context>
<context>
    <name>Plasmoid::Settings</name>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="29"/>
        <source>The settings on this page are specific to the current instance of the Plasmoid.</source>
        <translation>此页面上的设置特定于 Plasmoid 的当前实例。</translation>
    </message>
</context>
<context>
    <name>Plasmoid::SettingsDialog</name>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="126"/>
        <source>Plasmoid</source>
        <translation>Plasmoid</translation>
    </message>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="134"/>
        <source>Web view</source>
        <translation>网页视图</translation>
    </message>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="140"/>
        <source>Extras</source>
        <translation>额外</translation>
    </message>
</context>
<context>
    <name>Plasmoid::ShortcutOptionPage</name>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="66"/>
        <source>Shortcuts</source>
        <translation>快捷方式</translation>
    </message>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="72"/>
        <source>Global shortcut</source>
        <translation>全局快捷方式</translation>
    </message>
</context>
<context>
    <name>Plasmoid::SyncthingApplet</name>
    <message>
        <location filename="../lib/syncthingapplet.cpp" line="342"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <location filename="../lib/syncthingapplet.cpp" line="354"/>
        <source>New notifications</source>
        <translation>新通知</translation>
    </message>
    <message>
        <location filename="../lib/syncthingapplet.cpp" line="510"/>
        <source>D-Bus error - unable to </source>
        <translation>D-Bus 错误 - 无法 </translation>
    </message>
</context>
<context>
    <name>RecentChangesPage</name>
    <message>
        <location filename="../package/contents/ui/RecentChangesPage.qml" line="100"/>
        <source>Copy path</source>
        <translation>复制路径</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/RecentChangesPage.qml" line="105"/>
        <source>Copy device ID</source>
        <translation>复制设备 ID</translation>
    </message>
</context>
<context>
    <name>StatisticsView</name>
    <message>
        <location filename="../package/contents/ui/StatisticsView.qml" line="12"/>
        <source> files</source>
        <translation> 文件</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/StatisticsView.qml" line="17"/>
        <source> directories</source>
        <translation> 目录</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/StatisticsView.qml" line="23"/>
        <source> size</source>
        <translation> 大小</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../package/contents/ui/main.qml" line="67"/>
        <source>Open Syncthing</source>
        <translation>打开 Syncthing</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="69"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="70"/>
        <source>Log</source>
        <translation>日志</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="71"/>
        <source>Internal errors</source>
        <translation>内部错误</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="72"/>
        <source>Rescan all folders</source>
        <translation>重新扫描所有目录</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="74"/>
        <source>Restart Syncthing</source>
        <translation>重启 Syncthing</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="76"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
</context>
</TS>
